@@ -10,7 +10,12 @@
 # sys.setrecursionlimit(n)
 
 from pnap_network_api.model.error import Error
+from pnap_network_api.model.network_membership import NetworkMembership
 from pnap_network_api.model.private_network import PrivateNetwork
 from pnap_network_api.model.private_network_create import PrivateNetworkCreate
 from pnap_network_api.model.private_network_modify import PrivateNetworkModify
 from pnap_network_api.model.private_network_server import PrivateNetworkServer
+from pnap_network_api.model.public_network import PublicNetwork
+from pnap_network_api.model.public_network_create import PublicNetworkCreate
+from pnap_network_api.model.public_network_ip_block import PublicNetworkIpBlock
+from pnap_network_api.model.public_network_modify import PublicNetworkModify
